==> compiz-0.8.2-i486-5gsb.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libdecoration.so.0 )
( cd usr/lib ; ln -sf libdecoration.so.0.0.0 libdecoration.so.0 )
( cd usr/lib ; rm -rf libdecoration.so )
( cd usr/lib ; ln -sf libdecoration.so.0.0.0 libdecoration.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-annotate.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-blur.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-clone.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-commands.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-core.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-cube.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-dbus.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-decoration.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-fade.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-fs.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-gconf.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-glib.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-gnomecompat.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-ini.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-inotify.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-kconfig.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-minimize.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-move.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-obs.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-place.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-png.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-regex.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-resize.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-rotate.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-scale.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-screenshot.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-svg.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-switcher.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-video.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-water.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-wobbly.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-zoom.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gwd.schemas >/dev/null 2>&1
fi
# Preserve new configuration files
install_file() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

install_file etc/X11/xinit/xinitrc.compiz-gnome.new

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# Fix for weird white bar around menus and dock
usr/bin/gconftool-2 --direct --config-source=`usr/bin/gconftool-2 --get-default-source` --type string --set /apps/compiz/plugins/decoration/allscreens/options/shadow_match "2 !dock"1> /dev/null 2> /dev/null
# set default plugin list
usr/bin/gconftool-2 --direct --config-source=`usr/bin/gconftool-2 --get-default-source` --type list --set /apps/compiz/general/allscreens/options/active_plugins --list-type string "[core,workarounds,gnomecompat,dbus,resize,winrules,glib,svg,move,regex,decoration,png]" 1> /dev/null 2> /dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> compiz-0.8.6-i486-2gsb.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libdecoration.so.0 )
( cd usr/lib ; ln -sf libdecoration.so.0.0.0 libdecoration.so.0 )
( cd usr/lib ; rm -rf libdecoration.so )
( cd usr/lib ; ln -sf libdecoration.so.0.0.0 libdecoration.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-annotate.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-blur.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-clone.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-commands.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-core.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-cube.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-dbus.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-decoration.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-fade.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-fs.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-gconf.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-glib.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-gnomecompat.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-ini.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-inotify.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-kconfig.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-minimize.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-move.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-obs.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-place.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-png.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-regex.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-resize.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-rotate.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-scale.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-screenshot.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-svg.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-switcher.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-video.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-water.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-wobbly.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/compiz-zoom.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"     usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gwd.schemas >/dev/null 2>&1
fi
# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# Fix for weird white bar around menus and dock
usr/bin/gconftool-2 --direct --config-source="$(usr/bin/gconftool-2 --get-default-source)" --type string --set /apps/compiz/plugins/decoration/allscreens/options/shadow_match "2 \!dock"1> /dev/null 2> /dev/null
# set default plugin list
usr/bin/gconftool-2 --direct --config-source="$(usr/bin/gconftool-2 --get-default-source)" --type list --set /apps/compiz/general/allscreens/options/active_plugins --list-type string "[core,workarounds,gnomecompat,dbus,resize,winrules,glib,svg,move,regex,decoration,png]" 1> /dev/null 2> /dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
